@@ -1,25 +1,27 @@
 import pytz
+from itertools import groupby
 from datetime import datetime
 from events import Events
 from neo.Core.Block import Block
-from neo.Core.TX.Transaction import *
+from neo.Core.TX.Transaction import TransactionOutput
+from neo.Core.AssetType import AssetType
+from neocore.Cryptography.Crypto import Crypto
 from neo.Core.TX.RegisterTransaction import RegisterTransaction
 from neo.Core.TX.MinerTransaction import MinerTransaction
 from neo.Core.TX.IssueTransaction import IssueTransaction
 from neo.Core.Witness import Witness
-from neo.VM.OpCode import *
+from neo.VM.OpCode import PUSHF, PUSHT
 from neo.Core.State.SpentCoinState import SpentCoin
 from neo.SmartContract.Contract import Contract
 from neo.Settings import settings
-from neocore.Cryptography.Crypto import *
-from neocore.Cryptography.Helper import *
 from collections import Counter
 from neocore.Fixed8 import Fixed8
 from neocore.Cryptography.ECCurve import ECDSA
 from neocore.UInt256 import UInt256
+from functools import lru_cache
 
 
-class Blockchain(object):
+class Blockchain:
     SECONDS_PER_BLOCK = 15
 
     DECREMENT_INTERVAL = 2000000
@@ -58,6 +60,7 @@ class Blockchain(object):
         return Blockchain.__validators
 
     @staticmethod
+    @lru_cache(maxsize=2)
     def SystemShare():
         """
         Register AntShare.
@@ -73,6 +76,7 @@ class Blockchain(object):
                                    amount, 0, owner, admin)
 
     @staticmethod
+    @lru_cache(maxsize=2)
     def SystemCoin():
         """
         Register AntCoin
