@@ -1,18 +1,21 @@
-# -*- coding:utf-8 -*-
 """
 Description:
     Transaction Basic Class
 Usage:
     from neo.Core.Transaction import Transaction
 """
+import sys
 from itertools import groupby
-from neo.Blockchain import *
-from neo.Core.TX.TransactionAttribute import *
+import binascii
+from logzero import logger
+from neocore.UInt160 import UInt160
+from neo.Blockchain import GetBlockchain
+from neo.Core.TX.TransactionAttribute import TransactionAttributeUsage
 from neocore.Fixed8 import Fixed8
 
 from neo.Network.InventoryType import InventoryType
 from neo.Network.Mixins import InventoryMixin
-from neocore.Cryptography.Crypto import *
+from neocore.Cryptography.Crypto import Crypto
 from neocore.IO.Mixins import SerializableMixin
 from neo.IO.MemoryStream import StreamManager
 from neocore.IO.BinaryReader import BinaryReader
@@ -48,7 +51,7 @@ class TransactionResult(EquatableMixin):
         return "%s -> %s " % (self.AssetId.ToString(), self.Amount.value)
 
 
-class TransactionType(object):
+class TransactionType:
     MinerTransaction = b'\x00'
     IssueTransaction = b'\x01'
     ClaimTransaction = b'\x02'
@@ -355,6 +358,7 @@ class Transaction(InventoryMixin):
         Returns:
             int: size.
         """
+        # todo: will sys.getsizeof work as expected for each of these? is __sizeof__ implemented for each? should use Size() instead?
         len_attributes = sys.getsizeof(self.Attributes)
         len_inputs = sys.getsizeof(self.inputs)
         len_outputs = sys.getsizeof(self.outputs)
@@ -587,6 +591,8 @@ class Transaction(InventoryMixin):
         """
         jsn = {}
         jsn["txid"] = self.Hash.To0xString()
+        # todo: this size isn't calculating correctly currently, but it should be included in the JSON
+        # jsn["size"] = self.Size()
         jsn["type"] = TransactionType.ToName(self.Type)
         jsn["version"] = self.Version
         jsn["attributes"] = [attr.ToJson() for attr in self.Attributes]
