@@ -7,11 +7,8 @@ from neo.Core.TX.Transaction import Transaction
 from neo.Core.TX.MinerTransaction import MinerTransaction
 from neo.Network.NeoNode import NeoNode
 from neo.Settings import settings
-from twisted.internet.protocol import Factory, ReconnectingClientFactory
-from twisted.application.internet import ClientService
-from twisted.internet import reactor, task
-from twisted.internet.endpoints import clientFromString
-from twisted.application.internet import backoffPolicy
+from twisted.internet.protocol import ReconnectingClientFactory
+from twisted.internet import reactor
 
 
 class NeoClientFactory(ReconnectingClientFactory):
@@ -26,7 +23,7 @@ class NeoClientFactory(ReconnectingClientFactory):
                 peer.connectionLost()
 
 
-class NodeLeader():
+class NodeLeader:
     __LEAD = None
 
     Peers = []
@@ -39,16 +36,19 @@ class NodeLeader():
 
     _MissedBlocks = []
 
-    BREQPART = 20
-    NREQMAX = 100
+    BREQPART = 100
+    NREQMAX = 500
     BREQMAX = 10000
 
     KnownHashes = []
+    MissionsGlobal = []
     MemPool = {}
     RelayCache = {}
 
     NodeCount = 0
 
+    ServiceEnabled = False
+
     @staticmethod
     def Instance():
         """
@@ -67,6 +67,7 @@ class NodeLeader():
         This is the equivalent to C#'s LocalNode.cs
         """
         self.Setup()
+        self.ServiceEnabled = settings.SERVICE_ENABLED
 
     def Setup(self):
         """
@@ -78,6 +79,7 @@ class NodeLeader():
         self.Peers = []
         self.UnconnectedPeers = []
         self.ADDRS = []
+        self.MissionsGlobal = []
         self.NodeId = random.randint(1294967200, 4294967200)
 
     def Restart(self):
@@ -155,6 +157,7 @@ class NodeLeader():
     def ResetBlockRequestsAndCache(self):
         """Reset the block request counter and its cache."""
         logger.debug("Resseting Block requests")
+        self.MissionsGlobal = []
         BC.Default().BlockSearchTries = 0
         for p in self.Peers:
             p.myblockrequests = set()
@@ -249,6 +252,11 @@ class NodeLeader():
         # self.
         return relayed
 
+    def GetTransaction(self, hash):
+        if hash in self.MemPool.keys():
+            return self.MemPool[hash]
+        return None
+
     def AddTransaction(self, tx):
         """
         Add a transaction to the memory pool.
