@@ -1,9 +1,7 @@
 from neo.Utils.WalletFixtureTestCase import WalletFixtureTestCase
 from neo.Network.NodeLeader import NodeLeader
 from neo.Network.NeoNode import NeoNode
-from mock import patch, Mock, MagicMock
-import mock
-from twisted.internet import reactor
+from mock import patch
 from neo.Settings import settings
 from neo.Core.Blockchain import Blockchain
 from neocore.UInt160 import UInt160
@@ -11,11 +9,11 @@ from neocore.Fixed8 import Fixed8
 from neo.Implementations.Wallets.peewee.UserWallet import UserWallet
 from neo.Wallets.utils import to_aes_key
 from neo.SmartContract.ContractParameterContext import ContractParametersContext
-from neo.Core.TX.Transaction import Transaction, ContractTransaction, TransactionOutput
+from neo.Core.TX.Transaction import ContractTransaction, TransactionOutput
 from neo.Core.TX.MinerTransaction import MinerTransaction
 
 
-class Endpoint():
+class Endpoint:
     def __init__(self, host, port):
         self.host = host
         self.port = port
