@@ -1,4 +1,4 @@
-from neo.Prompt.Utils import get_arg, get_from_addr
+from neo.Prompt.Utils import get_arg, get_from_addr, get_tx_attr_from_args, get_owners_from_params
 from neo.Prompt.Commands.LoadSmartContract import GatherLoadedContractParams, generate_deploy_script
 from neo.SmartContract.ContractParameterType import ContractParameterType
 from neo.SmartContract.ContractParameter import ContractParameter
@@ -7,10 +7,10 @@ from neocore.Fixed8 import Fixed8
 from boa.compiler import Compiler
 from logzero import logger
 import binascii
-import traceback
 from neo.Core.State.ContractState import ContractPropertyState
 import os
 import json
+from neocore.BigInteger import BigInteger
 
 
 def LoadAndRun(arguments, wallet):
@@ -40,9 +40,12 @@ def LoadAndRun(arguments, wallet):
 
 
 def BuildAndRun(arguments, wallet, verbose=True, min_fee=DEFAULT_MIN_FEE, invocation_test_mode=True):
-    arguments, from_addr = get_from_addr(arguments)
-    path = get_arg(arguments)
+    print("arguments %s " % arguments)
 
+    arguments, from_addr = get_from_addr(arguments)
+    arguments, invoke_attrs = get_tx_attr_from_args(arguments)
+    arguments, owners = get_owners_from_params(arguments)
+    path = get_arg(arguments)
     contract_script = Compiler.instance().load_and_save(path)
 
     newpath = path.replace('.py', '.avm')
@@ -54,10 +57,14 @@ def BuildAndRun(arguments, wallet, verbose=True, min_fee=DEFAULT_MIN_FEE, invoca
         with open(debug_map_path, 'r') as dbg:
             debug_map = json.load(dbg)
 
-    return DoRun(contract_script, arguments, wallet, path, verbose, from_addr, min_fee, invocation_test_mode, debug_map=debug_map)
+    return DoRun(contract_script, arguments, wallet, path, verbose,
+                 from_addr, min_fee, invocation_test_mode,
+                 debug_map=debug_map, invoke_attrs=invoke_attrs, owners=owners)
 
 
-def DoRun(contract_script, arguments, wallet, path, verbose=True, from_addr=None, min_fee=DEFAULT_MIN_FEE, invocation_test_mode=True, debug_map=None):
+def DoRun(contract_script, arguments, wallet, path, verbose=True,
+          from_addr=None, min_fee=DEFAULT_MIN_FEE, invocation_test_mode=True,
+          debug_map=None, invoke_attrs=None, owners=None):
 
     test = get_arg(arguments, 1)
 
@@ -70,7 +77,9 @@ def DoRun(contract_script, arguments, wallet, path, verbose=True, from_addr=None
 
             script = GatherLoadedContractParams(f_args, contract_script)
 
-            tx, result, total_ops, engine = test_deploy_and_invoke(script, i_args, wallet, from_addr, min_fee, invocation_test_mode, debug_map=debug_map)
+            tx, result, total_ops, engine = test_deploy_and_invoke(script, i_args, wallet, from_addr,
+                                                                   min_fee, invocation_test_mode, debug_map=debug_map,
+                                                                   invoke_attrs=invoke_attrs, owners=owners)
             i_args.reverse()
 
             return_type_results = []
@@ -106,13 +115,16 @@ def DoRun(contract_script, arguments, wallet, path, verbose=True, from_addr=None
     return None, None, None, None
 
 
-def TestBuild(script, invoke_args, wallet, plist='05', ret='05', dynamic=False):
+def TestBuild(script, invoke_args, wallet, plist='05', ret='05', dynamic=False, invoke_attrs=None, owners=None):
 
     properties = ContractPropertyState.HasStorage
 
     if dynamic:
         properties += ContractPropertyState.HasDynamicInvoke
 
-    script = generate_deploy_script(script, contract_properties=int(properties), parameter_list=plist, return_type=ret)
+    if not isinstance(ret, bytearray):
+        ret = bytearray(binascii.unhexlify(str(ret).encode('utf-8')))
 
-    return test_deploy_and_invoke(script, invoke_args, wallet)
+    script = generate_deploy_script(script, contract_properties=int(properties), parameter_list=plist, return_type=BigInteger.FromBytes(ret))
+
+    return test_deploy_and_invoke(script, invoke_args, wallet, invoke_attrs=invoke_attrs, owners=owners)
