@@ -1,9 +1,10 @@
+import binascii
+import json
 from neo.Blockchain import GetBlockchain
 from neo.VM.ScriptBuilder import ScriptBuilder
 from neo.VM.InteropService import InteropInterface
 from neo.Network.NodeLeader import NodeLeader
-from neo.Prompt.Utils import parse_param, get_asset_attachments, lookup_addr_str
-
+from neo.Prompt.Utils import parse_param, get_asset_attachments, lookup_addr_str, get_owners_from_params
 
 from neo.Implementations.Blockchains.LevelDB.DBCollection import DBCollection
 from neo.Implementations.Blockchains.LevelDB.DBPrefix import DBPrefix
@@ -25,35 +26,37 @@ from neo.SmartContract import TriggerType
 from neo.SmartContract.StateMachine import StateMachine
 from neo.SmartContract.ContractParameterContext import ContractParametersContext
 from neo.SmartContract.Contract import Contract
+from neocore.Cryptography.Helper import scripthash_to_address
 from neocore.Cryptography.Crypto import Crypto
 from neocore.Fixed8 import Fixed8
 from neo.Settings import settings
-from neo.Core.Helper import Helper
 from neo.Core.Blockchain import Blockchain
 from neo.EventHub import events
 from logzero import logger
+from prompt_toolkit import prompt
+
+from neocore.Cryptography.ECCurve import ECDSA
+
+from neo.VM.OpCode import PACK
 
-from neo.VM.OpCode import *
-import json
-from twisted.internet import reactor
 DEFAULT_MIN_FEE = Fixed8.FromDecimal(.0001)
 
 
-def InvokeContract(wallet, tx, fee=Fixed8.Zero(), from_addr=None):
+def InvokeContract(wallet, tx, fee=Fixed8.Zero(), from_addr=None, owners=None):
 
     if from_addr is not None:
         from_addr = lookup_addr_str(wallet, from_addr)
 
     wallet_tx = wallet.MakeTransaction(tx=tx, fee=fee, use_standard=True, from_addr=from_addr)
 
-#    pdb.set_trace()
-
     if wallet_tx:
 
         context = ContractParametersContext(wallet_tx)
-
         wallet.Sign(context)
 
+        if owners:
+            gather_signatures(context, wallet_tx, list(owners))
+
         if context.Completed:
 
             wallet_tx.scripts = context.GetScripts()
@@ -82,7 +85,7 @@ def InvokeContract(wallet, tx, fee=Fixed8.Zero(), from_addr=None):
     return False
 
 
-def InvokeWithTokenVerificationScript(wallet, tx, token, fee=Fixed8.Zero()):
+def InvokeWithTokenVerificationScript(wallet, tx, token, fee=Fixed8.Zero(), invoke_attrs=None):
 
     wallet_tx = wallet.MakeTransaction(tx=tx, fee=fee, use_standard=True)
 
@@ -96,6 +99,9 @@ def InvokeWithTokenVerificationScript(wallet, tx, token, fee=Fixed8.Zero()):
                                  data=token.ScriptHash.Data)
         ]
 
+        if invoke_attrs:
+            tx.Attributes += invoke_attrs
+
         reedeem_script = token_contract_state.Code.Script.hex()
 
         # there has to be at least 1 param, and the first
@@ -114,12 +120,6 @@ def InvokeWithTokenVerificationScript(wallet, tx, token, fee=Fixed8.Zero()):
 
             wallet_tx.scripts = context.GetScripts()
 
-            relayed = False
-
-#            print("full wallet tx: %s " % json.dumps(wallet_tx.ToJson(), indent=4))
-#            toarray = Helper.ToArray(wallet_tx)
-#            print("to arary %s " % toarray)
-
             relayed = NodeLeader.Instance().Relay(wallet_tx)
 
             if relayed:
@@ -141,29 +141,19 @@ def InvokeWithTokenVerificationScript(wallet, tx, token, fee=Fixed8.Zero()):
     return False
 
 
-def TestInvokeContract(wallet, args, withdrawal_tx=None, parse_params=True, from_addr=None, min_fee=DEFAULT_MIN_FEE):
+def TestInvokeContract(wallet, args, withdrawal_tx=None,
+                       parse_params=True, from_addr=None,
+                       min_fee=DEFAULT_MIN_FEE, invoke_attrs=None, owners=None):
 
     BC = GetBlockchain()
 
     contract = BC.GetContract(args[0])
 
     if contract:
-
-        verbose = False
-
-        if 'verbose' in args:
-            descripe_contract(contract)
-            verbose = True
-            args.remove('verbose')
-
-#
+        #
         params = args[1:] if len(args) > 1 else []
 
-        if len(params) > 0 and params[0] == 'describe':
-            return
-
         params, neo_to_attach, gas_to_attach = get_asset_attachments(params)
-
         params.reverse()
 
         sb = ScriptBuilder()
@@ -174,12 +164,21 @@ def TestInvokeContract(wallet, args, withdrawal_tx=None, parse_params=True, from
                 item = parse_param(p, wallet)
             else:
                 item = p
-
             if type(item) is list:
                 item.reverse()
                 listlength = len(item)
                 for listitem in item:
-                    sb.push(listitem)
+                    subitem = parse_param(listitem, wallet)
+                    if type(subitem) is list:
+                        subitem.reverse()
+                        for listitem2 in subitem:
+                            subsub = parse_param(listitem2, wallet)
+                            sb.push(subsub)
+                        sb.push(len(subitem))
+                        sb.Emit(PACK)
+                    else:
+                        sb.push(subitem)
+
                 sb.push(listlength)
                 sb.Emit(PACK)
             else:
@@ -207,7 +206,7 @@ def TestInvokeContract(wallet, args, withdrawal_tx=None, parse_params=True, from
 
             outputs.append(output)
 
-        return test_invoke(out, wallet, outputs, withdrawal_tx, from_addr, min_fee)
+        return test_invoke(out, wallet, outputs, withdrawal_tx, from_addr, min_fee, invoke_attrs=invoke_attrs, owners=owners)
 
     else:
 
@@ -216,7 +215,9 @@ def TestInvokeContract(wallet, args, withdrawal_tx=None, parse_params=True, from
     return None, None, None, None
 
 
-def test_invoke(script, wallet, outputs, withdrawal_tx=None, from_addr=None, min_fee=DEFAULT_MIN_FEE):
+def test_invoke(script, wallet, outputs, withdrawal_tx=None,
+                from_addr=None, min_fee=DEFAULT_MIN_FEE,
+                invoke_attrs=None, owners=None):
 
     # print("invoke script %s " % script)
 
@@ -247,13 +248,14 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None, from_addr=None, min
     tx.Version = 1
     tx.scripts = []
     tx.Script = binascii.unhexlify(script)
+    tx.Attributes = [] if invoke_attrs is None else invoke_attrs
 
     script_table = CachedScriptTable(contracts)
     service = StateMachine(accounts, validators, assets, contracts, storages, None)
 
     if len(outputs) < 1:
         contract = wallet.GetDefaultContract()
-        tx.Attributes = [TransactionAttribute(usage=TransactionAttributeUsage.Script, data=Crypto.ToScriptHash(contract.Script, unhex=False).Data)]
+        tx.Attributes.append(TransactionAttribute(usage=TransactionAttributeUsage.Script, data=contract.ScriptHash))
 
     # same as above. we don't want to re-make the transaction if it is a withdrawal tx
     if withdrawal_tx is not None:
@@ -261,12 +263,23 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None, from_addr=None, min
     else:
         wallet_tx = wallet.MakeTransaction(tx=tx, from_addr=from_addr)
 
-    if wallet_tx:
+    context = ContractParametersContext(wallet_tx)
+    wallet.Sign(context)
 
-        context = ContractParametersContext(wallet_tx)
-        wallet.Sign(context)
-        if context.Completed:
-            wallet_tx.scripts = context.GetScripts()
+    if owners:
+        owners = list(owners)
+        for owner in owners:
+            #            print("contract %s %s" % (wallet.GetDefaultContract().ScriptHash, owner))
+            if wallet.GetDefaultContract().ScriptHash != owner:
+                wallet_tx.Attributes.append(TransactionAttribute(usage=TransactionAttributeUsage.Script, data=owner))
+        context = ContractParametersContext(wallet_tx, isMultiSig=True)
+
+    if context.Completed:
+        wallet_tx.scripts = context.GetScripts()
+    else:
+        logger.warn("Not gathering signatures for test build.  For a non-test invoke that would occur here.")
+#        if not gather_signatures(context, wallet_tx, owners):
+#            return None, [], 0, None
 
     engine = ApplicationEngine(
         trigger_type=TriggerType.Application,
@@ -280,7 +293,6 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None, from_addr=None, min
     engine.LoadScript(wallet_tx.Script, False)
 
     try:
-        # drum roll?
         success = engine.Execute()
 
         service.ExecutionCompleted(engine, success)
@@ -318,6 +330,12 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None, from_addr=None, min
 
             return wallet_tx, net_fee, engine.EvaluationStack.Items, engine.ops_processed
 
+        # this allows you to to test invocations that fail
+        else:
+            wallet_tx.outputs = outputs
+            wallet_tx.Attributes = []
+            return wallet_tx, min_fee, [], engine.ops_processed
+
     except Exception as e:
         service.ExecutionCompleted(engine, False, e)
 #        print("COULD NOT EXECUTE %s " % e)
@@ -325,7 +343,9 @@ def test_invoke(script, wallet, outputs, withdrawal_tx=None, from_addr=None, min
     return None, None, None, None
 
 
-def test_deploy_and_invoke(deploy_script, invoke_args, wallet, from_addr=None, min_fee=DEFAULT_MIN_FEE, invocation_test_mode=True, debug_map=None):
+def test_deploy_and_invoke(deploy_script, invoke_args, wallet,
+                           from_addr=None, min_fee=DEFAULT_MIN_FEE, invocation_test_mode=True,
+                           debug_map=None, invoke_attrs=None, owners=None):
 
     bc = GetBlockchain()
 
@@ -400,23 +420,27 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet, from_addr=None, m
         shash = contract_state.Code.ScriptHash()
 
         invoke_args, neo_to_attach, gas_to_attach = get_asset_attachments(invoke_args)
-
         invoke_args.reverse()
 
-        # print("neo, gas %s %s " % (neo_to_attach,gas_to_attach.ToString()))
-
         sb = ScriptBuilder()
 
         for p in invoke_args:
-
             item = parse_param(p, wallet)
-
             if type(item) is list:
                 item.reverse()
                 listlength = len(item)
                 for listitem in item:
                     subitem = parse_param(listitem, wallet)
-                    sb.push(subitem)
+                    if type(subitem) is list:
+                        subitem.reverse()
+                        for listitem2 in subitem:
+                            subsub = parse_param(listitem2, wallet)
+                            sb.push(subsub)
+                        sb.push(len(subitem))
+                        sb.Emit(PACK)
+                    else:
+                        sb.push(subitem)
+
                 sb.push(listlength)
                 sb.Emit(PACK)
             else:
@@ -446,20 +470,33 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet, from_addr=None, m
         itx.outputs = outputs
         itx.inputs = []
         itx.scripts = []
-        itx.Attributes = []
+        itx.Attributes = invoke_attrs if invoke_attrs else []
         itx.Script = binascii.unhexlify(out)
 
-        if len(outputs) < 1:
+        if len(outputs) < 1 and not owners:
             contract = wallet.GetDefaultContract()
-            itx.Attributes = [TransactionAttribute(usage=TransactionAttributeUsage.Script,
-                                                   data=Crypto.ToScriptHash(contract.Script, unhex=False).Data)]
+            itx.Attributes.append(TransactionAttribute(usage=TransactionAttributeUsage.Script,
+                                                       data=contract.ScriptHash))
 
         itx = wallet.MakeTransaction(tx=itx, from_addr=from_addr)
+
         context = ContractParametersContext(itx)
         wallet.Sign(context)
-        itx.scripts = context.GetScripts()
 
-#            print("tx: %s " % json.dumps(itx.ToJson(), indent=4))
+        if owners:
+            owners = list(owners)
+            for owner in owners:
+                itx.Attributes.append(TransactionAttribute(usage=TransactionAttributeUsage.Script, data=owner))
+            context = ContractParametersContext(itx, isMultiSig=True)
+
+        if context.Completed:
+            itx.scripts = context.GetScripts()
+        else:
+            logger.warn("Not gathering signatures for test build.  For a non-test invoke that would occur here.")
+#            if not gather_signatures(context, itx, owners):
+#                return None, [], 0, None
+
+#        print("gathered signatures %s " % itx.scripts)
 
         engine = ApplicationEngine(
             trigger_type=TriggerType.Application,
@@ -471,7 +508,7 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet, from_addr=None, m
         )
 
         engine.LoadScript(itx.Script, False)
-        engine.LoadDebugInfo(debug_map)
+        engine.LoadDebugInfoForScriptHash(debug_map, shash.Data)
 
         # call execute in its own blocking thread
 
@@ -490,7 +527,6 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet, from_addr=None, m
             if len(service.notifications) > 0:
 
                 for n in service.notifications:
-                    #                        print("NOTIFICATION : %s " % n)
                     Blockchain.Default().OnNotify(n)
 
             logger.info("Used %s Gas " % engine.GasConsumed().ToString())
@@ -519,5 +555,46 @@ def test_deploy_and_invoke(deploy_script, invoke_args, wallet, from_addr=None, m
     return None, [], 0, None
 
 
-def descripe_contract(contract):
-    print("invoking contract - %s" % contract.Name.decode('utf-8'))
+def gather_signatures(context, itx, owners):
+    do_exit = False
+    print("owners %s " % owners)
+    print("\n\n*******************\n")
+    print("Gather Signatures for Transactino:\n%s " % json.dumps(itx.ToJson(), indent=4))
+    print("Please use a client to sign the following: %s " % itx.GetHashData())
+
+    owner_index = 0
+    while not context.Completed and not do_exit:
+
+        next_script = owners[owner_index]
+        next_addr = scripthash_to_address(next_script.Data)
+        try:
+            print("\n*******************\n")
+            owner_input = prompt('Public Key and Signature for %s> ' % next_addr)
+            items = owner_input.split(' ')
+            pubkey = ECDSA.decode_secp256r1(items[0]).G
+            sig = items[1]
+            contract = Contract.CreateSignatureContract(pubkey)
+
+            if contract.Address == next_addr:
+                context.Add(contract, 0, sig)
+                print("Adding signature %s " % sig)
+                owner_index += 1
+            else:
+                print("Public Key does not match address %s " % next_addr)
+
+        except EOFError:
+            # Control-D pressed: quit
+            do_exit = True
+        except KeyboardInterrupt:
+            # Control-C pressed: do nothing
+            do_exit = True
+        except Exception as e:
+            print("Could not parse input %s " % e)
+
+    if context.Completed:
+        print("Signatures complete")
+        itx.scripts = context.GetScripts()
+        return True
+    else:
+        print("Could not finish signatures")
+        return False
