@@ -38,6 +38,30 @@ def get_asset_attachments(params):
     return params, neo_to_attach, gas_to_attach
 
 
+def get_owners_from_params(params):
+    to_remove = []
+    owners = None
+
+    for item in params:
+        if type(item) is str:
+            if '--owners=' in item:
+                owners = []
+                to_remove.append(item)
+                try:
+                    owner_list = eval(item.replace('--owners=', ''))
+                    owners = set()
+                    for o in owner_list:
+                        shash = Helper.AddrStrToScriptHash(o)
+                        owners.add(shash)
+                except Exception as e:
+                    logger.info("Could not parse owner %s " % e)
+                    pass
+    for item in to_remove:
+        params.remove(item)
+
+    return params, owners
+
+
 def get_asset_id(wallet, asset_str):
     assetId = None
 
@@ -114,7 +138,10 @@ def get_tx_attr_from_args(params):
             to_remove.append(item)
             try:
                 attr_str = item.replace('--tx-attr=', '')
-                tx_attr_obj = json.loads(attr_str)
+
+# this doesn't work for loading in bytearrays
+#                tx_attr_obj = json.loads(attr_str)
+                tx_attr_obj = eval(attr_str)
                 if type(tx_attr_obj) is dict:
                     if attr_obj_to_tx_attr(tx_attr_obj) is not None:
                         tx_attr_dict.append(attr_obj_to_tx_attr(tx_attr_obj))
@@ -148,7 +175,7 @@ def parse_param(p, wallet=None, ignore_int=False, prefer_hex=True):
 
     # first, we'll try to parse an array
     try:
-        items = eval(p, {"__builtins__": {}}, {})
+        items = eval(p, {"__builtins__": {'list': list}}, {})
         if len(items) > 0 and type(items) is list:
 
             parsed = []
@@ -169,12 +196,20 @@ def parse_param(p, wallet=None, ignore_int=False, prefer_hex=True):
             pass
 
     try:
-        val = eval(p, {"__builtins__": {}}, {})
-
+        val = eval(p, {"__builtins__": {'bytearray': bytearray, 'bytes': bytes, 'list': list}}, {})
         if type(val) is bytearray:
-            return val.hex()
+            return val
+        elif type(val) is bytes:
+            # try to unhex
+            try:
+                val = binascii.unhexlify(val)
+            except Exception as e:
+                pass
+            # now it should be unhexxed no matter what, and we can hex it
+            return val.hex().encode('utf-8')
+        elif type(val) is bool:
+            return val
 
-        return val
     except Exception as e:
         pass
 
@@ -225,12 +260,11 @@ def lookup_addr_str(wallet, addr):
 
 
 def parse_hold_vins(results):
-    print("results!!! %s " % results)
 
     holds = results[0].GetByteArray()
     holdlen = len(holds)
     numholds = int(holdlen / 33)
-    print("holds, holdlen, numholds %s %s " % (holds, numholds))
+
     vins = []
     for i in range(0, numholds):
         hstart = i * 33
@@ -239,12 +273,9 @@ def parse_hold_vins(results):
 
         vin_index = item[0]
         vin_tx_id = UInt256(data=item[1:])
-        print("VIN INDEX, VIN TX ID: %s %s" % (vin_index, vin_tx_id))
 
         t_input = TransactionInput(prevHash=vin_tx_id, prevIndex=vin_index)
 
-        print("found tinput: %s " % json.dumps(t_input.ToJson(), indent=4))
-
         vins.append(t_input)
 
     return vins
