@@ -105,6 +105,8 @@ class SettingsHolder:
 
     CONNECTED_PEER_MAX = 5
 
+    SERVICE_ENABLED = True
+
     VERSION_NAME = "/NEO-PYTHON:%s/" % __version__
 
     # Logging settings
@@ -199,6 +201,9 @@ class SettingsHolder:
         if 'NotificationDataPath' in config:
             self.NOTIFICATION_DB_PATH = config['NotificationDataPath']
 
+        if 'ServiceEnabled' in config:
+            self.SERVICE_ENABLED = bool(config['ServiceEnabled'])
+
     def setup_mainnet(self):
         """ Load settings from the mainnet JSON config file """
         self.setup(FILENAME_SETTINGS_MAINNET)
@@ -236,6 +241,10 @@ class SettingsHolder:
         else:
             self.DATA_DIR_PATH = path
 
+        if not os.path.exists(self.DATA_DIR_PATH):
+            logzero.logger.info("Data directory %s does not yet exist. Creating...", self.DATA_DIR_PATH)
+            os.makedirs(self.DATA_DIR_PATH)
+
     def set_max_peers(self, num_peers):
         try:
             self.CONNECTED_PEER_MAX = int(num_peers)
@@ -317,7 +326,7 @@ class SettingsHolder:
             if nonce_chain != nonce_container:
                 raise PrivnetConnectionError(
                     "Chain database in Chains/privnet is for a different private network than the current container. "
-                    "Consider deleting the Chain directory with 'rm -rf %s/privnet*'." % self.chain_leveldb_path
+                    "Consider deleting the Chain directory with 'rm -rf %s*'." % self.chain_leveldb_path
                 )
         else:
             # When the Chains/privnet folder is removed, we need to create the directory
@@ -340,8 +349,9 @@ settings.set_loglevel(logging.INFO)
 
 # System check: Are dependencies must be installed in the correct version
 # Can be bypassed with `SKIP_DEPS_CHECK=1 python prompt.py`
-if not os.getenv("SKIP_DEPS_CHECK") and not IS_PACKAGE_INSTALL:
-    check_depdendencies()
+# this causes so many headaches when developing between boa and neo and core... :(
+# if not os.getenv("SKIP_DEPS_CHECK") and not IS_PACKAGE_INSTALL:
+#     check_depdendencies()
 
 # System check: Python 3.6+
 if not os.getenv("SKIP_PY_CHECK"):
