@@ -15,22 +15,14 @@ from neocore.Cryptography.ECCurve import ECDSA
 from neocore.UInt160 import UInt160
 from neocore.UInt256 import UInt256
 from neocore.Fixed8 import Fixed8
-from neo.VM.InteropService import StackItem, stack_item_to_py
+from neo.VM.InteropService import StackItem
 from neo.SmartContract.StorageContext import StorageContext
 from neo.SmartContract.StateReader import StateReader
-from neo.EventHub import dispatch_smart_contract_event, SmartContractEvent
-
-import pdb
+from neo.EventHub import SmartContractEvent
 
 
 class StateMachine(StateReader):
-
-    _accounts = None
     _validators = None
-    _assets = None
-    _contracts = None
-    _storages = None
-
     _wb = None
 
     _contracts_created = {}
@@ -68,23 +60,13 @@ class StateMachine(StateReader):
         self.Register("AntShares.Storage.Put", self.Storage_Put)
         self.Register("AntShares.Storage.Delete", self.Storage_Delete)
 
-    def CheckStorageContext(self, context):
-        if context is None:
-            return False
-
-        contract = self._contracts.TryGet(context.ScriptHash.ToBytes())
-
-        if contract is not None:
-            if contract.HasStorage:
-                return True
-
-        return False
-
     def ExecutionCompleted(self, engine, success, error=None):
 
         # commit storages right away
         if success:
             self.Commit()
+        else:
+            self.ResetState()
 
         super(StateMachine, self).ExecutionCompleted(engine, success, error)
 
@@ -96,6 +78,13 @@ class StateMachine(StateReader):
             self._contracts.Commit(self._wb, False)
             self._storages.Commit(self._wb, False)
 
+    def ResetState(self):
+        self._accounts.Reset()
+        self._validators.Reset()
+        self._assets.Reset()
+        self._contracts.Reset()
+        self._storages.Reset()
+
     def TestCommit(self):
         if self._storages.DebugStorage:
             self._storages.Commit(self._wb, False)
@@ -109,7 +98,6 @@ class StateMachine(StateReader):
         if account:
             engine.EvaluationStack.PushT(StackItem.FromInterface(account))
         else:
-            print("no account")
             engine.EvaluationStack.PushT(False)
 
         return True
@@ -194,7 +182,6 @@ class StateMachine(StateReader):
                 asset_type == AssetType.DutyFlag or \
                 asset_type == AssetType.GoverningToken or \
                 asset_type == AssetType.UtilityToken:
-
             return False
 
         if len(engine.EvaluationStack.Peek().GetByteArray()) > 1024:
@@ -327,7 +314,6 @@ class StateMachine(StateReader):
         contract = self._contracts.TryGet(hash.ToBytes())
 
         if contract is None:
-
             code = FunctionCode(script=script, param_list=param_list, return_type=return_type, contract_properties=contract_properties)
 
             contract = ContractState(code, contract_properties, name, code_version, author, email, description)
@@ -340,7 +326,7 @@ class StateMachine(StateReader):
 
         self.events_to_dispatch.append(
             SmartContractEvent(SmartContractEvent.CONTRACT_CREATED, [contract],
-                               hash, Blockchain.Default().Height,
+                               hash, Blockchain.Default().Height + 1,
                                engine.ScriptContainer.Hash if engine.ScriptContainer else None,
                                test_mode=engine.testMode))
         return True
@@ -399,18 +385,16 @@ class StateMachine(StateReader):
             self._contracts_created[hash.ToBytes()] = UInt160(data=engine.CurrentContext.ScriptHash())
 
             if contract.HasStorage:
-
-                for pair in self._storages.Find(engine.CurrentContext.ScriptHash()):
-
-                    key = StorageKey(script_hash=hash, key=pair.Key.Key)
-                    item = StorageItem(pair.Value.Value)
-                    self._storages.Add(key, item)
+                for key, val in self._storages.Find(engine.CurrentContext.ScriptHash()).items():
+                    key = StorageKey(script_hash=hash, key=key)
+                    item = StorageItem(val)
+                    self._storages.Add(key.ToArray(), item)
 
         engine.EvaluationStack.PushT(StackItem.FromInterface(contract))
 
         self.events_to_dispatch.append(
             SmartContractEvent(SmartContractEvent.CONTRACT_MIGRATED, [contract],
-                               hash, Blockchain.Default().Height,
+                               hash, Blockchain.Default().Height + 1,
                                engine.ScriptContainer.Hash if engine.ScriptContainer else None,
                                test_mode=engine.testMode))
 
@@ -427,7 +411,6 @@ class StateMachine(StateReader):
             created = self._contracts_created[shash.ToBytes()]
 
             if created == UInt160(data=engine.CurrentContext.ScriptHash()):
-
                 context = StorageContext(script_hash=shash)
                 engine.EvaluationStack.PushT(StackItem.FromInterface(context))
 
@@ -447,12 +430,11 @@ class StateMachine(StateReader):
             if contract.HasStorage:
 
                 for pair in self._storages.Find(hash.ToBytes()):
-
                     self._storages.Remove(pair.Key)
 
         self.events_to_dispatch.append(
             SmartContractEvent(SmartContractEvent.CONTRACT_DESTROY, [contract],
-                               hash, Blockchain.Default().Height,
+                               hash, Blockchain.Default().Height + 1,
                                engine.ScriptContainer.Hash if engine.ScriptContainer else None,
                                test_mode=engine.testMode))
         return True
@@ -472,7 +454,7 @@ class StateMachine(StateReader):
 
         key = engine.EvaluationStack.Pop().GetByteArray()
         storage_key = StorageKey(script_hash=context.ScriptHash, key=key)
-        item = self._storages.TryGet(storage_key.GetHashCodeBytes())
+        item = self._storages.TryGet(storage_key.ToArray())
 
         keystr = key
 
@@ -498,7 +480,7 @@ class StateMachine(StateReader):
 
         self.events_to_dispatch.append(
             SmartContractEvent(SmartContractEvent.STORAGE_GET, ['%s -> %s' % (keystr, valStr)],
-                               context.ScriptHash, Blockchain.Default().Height,
+                               context.ScriptHash, Blockchain.Default().Height + 1,
                                engine.ScriptContainer.Hash if engine.ScriptContainer else None,
                                test_mode=engine.testMode))
 
@@ -525,7 +507,7 @@ class StateMachine(StateReader):
 
         new_item = StorageItem(value=value)
         storage_key = StorageKey(script_hash=context.ScriptHash, key=key)
-        item = self._storages.GetOrAdd(storage_key.GetHashCodeBytes(), new_item)
+        item = self._storages.GetOrAdd(storage_key.ToArray(), new_item)
 
         keystr = key
         valStr = bytearray(item.Value)
@@ -540,7 +522,7 @@ class StateMachine(StateReader):
 
         self.events_to_dispatch.append(
             SmartContractEvent(SmartContractEvent.STORAGE_PUT, ['%s -> %s' % (keystr, valStr)],
-                               context.ScriptHash, Blockchain.Default().Height,
+                               context.ScriptHash, Blockchain.Default().Height + 1,
                                engine.ScriptContainer.Hash if engine.ScriptContainer else None,
                                test_mode=engine.testMode))
 
@@ -557,14 +539,15 @@ class StateMachine(StateReader):
 
         storage_key = StorageKey(script_hash=context.ScriptHash, key=key)
 
+        keystr = key
         if len(key) == 20:
             keystr = Crypto.ToAddress(UInt160(data=key))
 
-            self.events_to_dispatch.append(SmartContractEvent(SmartContractEvent.STORAGE_DELETE, [keystr],
-                                                              context.ScriptHash, Blockchain.Default().Height,
-                                                              engine.ScriptContainer.Hash if engine.ScriptContainer else None,
-                                                              test_mode=engine.testMode))
+        self.events_to_dispatch.append(SmartContractEvent(SmartContractEvent.STORAGE_DELETE, [keystr],
+                                                          context.ScriptHash, Blockchain.Default().Height + 1,
+                                                          engine.ScriptContainer.Hash if engine.ScriptContainer else None,
+                                                          test_mode=engine.testMode))
 
-        self._storages.Remove(storage_key.GetHashCodeBytes())
+        self._storages.Remove(storage_key.ToArray())
 
         return True
