@@ -1,6 +1,4 @@
-import events
 import binascii
-import pdb
 
 from logzero import logger
 
@@ -9,18 +7,18 @@ from neo.SmartContract.Contract import Contract
 from neo.SmartContract.NotifyEventArgs import NotifyEventArgs
 from neo.SmartContract.StorageContext import StorageContext
 from neo.Core.State.StorageKey import StorageKey
-from neo.Core.State.StorageItem import StorageItem
 from neo.Core.Blockchain import Blockchain
 from neocore.Cryptography.Crypto import Crypto
 from neocore.BigInteger import BigInteger
 from neocore.UInt160 import UInt160
 from neocore.UInt256 import UInt256
-from neo.EventHub import dispatch_smart_contract_event, dispatch_smart_contract_notify
 from neo.SmartContract.SmartContractEvent import SmartContractEvent, NotifyEvent
 from neocore.Cryptography.ECCurve import ECDSA
 from neo.SmartContract.TriggerType import Application, Verification
 from neo.VM.InteropService import StackItem, stack_item_to_py, ByteArray
 from neo.Settings import settings
+from neo.Implementations.Blockchains.LevelDB.DBPrefix import DBPrefix
+from neo.Implementations.Blockchains.LevelDB.DBCollection import DBCollection
 from neocore.IO.BinaryReader import BinaryReader
 from neocore.IO.BinaryWriter import BinaryWriter
 from neo.IO.MemoryStream import StreamManager
@@ -35,6 +33,11 @@ class StateReader(InteropService):
 
     _hashes_for_verifying = None
 
+    _accounts = None
+    _assets = None
+    _contracts = None
+    _storages = None
+
     @staticmethod
     def Instance():
         if StateReader.__Instance is None:
@@ -114,6 +117,10 @@ class StateReader(InteropService):
 
         self.Register("Neo.Storage.GetContext", self.Storage_GetContext)
         self.Register("Neo.Storage.Get", self.Storage_Get)
+        self.Register("Neo.Storage.Find", self.Storage_Find)
+        self.Register("Neo.Iterator.Next", self.Iterator_Next)
+        self.Register("Neo.Iterator.Key", self.Iterator_Key)
+        self.Register("Neo.Iterator.Value", self.Iterator_Value)
 
         # OLD API
 
@@ -178,9 +185,21 @@ class StateReader(InteropService):
         self.Register("AntShares.Storage.GetContext", self.Storage_GetContext)
         self.Register("AntShares.Storage.Get", self.Storage_Get)
 
+    def CheckStorageContext(self, context):
+        if context is None:
+            return False
+
+        contract = self._contracts.TryGet(context.ScriptHash.ToBytes())
+
+        if contract is not None:
+            if contract.HasStorage:
+                return True
+
+        return False
+
     def ExecutionCompleted(self, engine, success, error=None):
 
-        height = Blockchain.Default().Height
+        height = Blockchain.Default().Height + 1
         tx_hash = None
 
         if engine.ScriptContainer:
@@ -257,9 +276,6 @@ class StateReader(InteropService):
 
         hashOrPubkey = engine.EvaluationStack.Pop().GetByteArray()
 
-        if len(hashOrPubkey) == 66 or len(hashOrPubkey) == 40:
-            hashOrPubkey = binascii.unhexlify(hashOrPubkey)
-
         result = False
 
         if len(hashOrPubkey) == 20:
@@ -269,7 +285,7 @@ class StateReader(InteropService):
             point = ECDSA.decode_secp256r1(hashOrPubkey, unhex=False).G
             result = self.CheckWitnessPubkey(engine, point)
         else:
-            result = False
+            return False
 
         engine.EvaluationStack.PushT(result)
 
@@ -297,7 +313,7 @@ class StateReader(InteropService):
         if settings.emit_notify_events_on_sc_execution_error:
             # emit Notify events even if the SC execution might fail.
             tx_hash = engine.ScriptContainer.Hash
-            height = Blockchain.Default().Height
+            height = Blockchain.Default().Height + 1
             success = None
             self.events_to_dispatch.append(NotifyEvent(SmartContractEvent.RUNTIME_NOTIFY, args.State,
                                                        args.ScriptHash, height, tx_hash,
@@ -320,7 +336,7 @@ class StateReader(InteropService):
         self.events_to_dispatch.append(SmartContractEvent(SmartContractEvent.RUNTIME_LOG,
                                                           [message],
                                                           hash,
-                                                          Blockchain.Default().Height,
+                                                          Blockchain.Default().Height + 1,
                                                           tx_hash,
                                                           test_mode=engine.testMode))
 
@@ -485,7 +501,8 @@ class StateReader(InteropService):
 
         if Blockchain.Default() is not None:
             asset = Blockchain.Default().GetAssetState(UInt256(data=data))
-
+        if asset is None:
+            return False
         engine.EvaluationStack.PushT(StackItem.FromInterface(asset))
         return True
 
@@ -495,7 +512,8 @@ class StateReader(InteropService):
 
         if Blockchain.Default() is not None:
             contract = Blockchain.Default().GetContract(hash)
-
+        if contract is None:
+            return False
         engine.EvaluationStack.PushT(StackItem.FromInterface(contract))
         return True
 
@@ -896,6 +914,46 @@ class StateReader(InteropService):
             engine.EvaluationStack.PushT(bytearray(0))
 
         self.events_to_dispatch.append(SmartContractEvent(SmartContractEvent.STORAGE_GET, ['%s -> %s' % (keystr, valStr)],
-                                                          context.ScriptHash, Blockchain.Default().Height, engine.ScriptContainer.Hash, test_mode=engine.testMode))
+                                                          context.ScriptHash, Blockchain.Default().Height + 1, engine.ScriptContainer.Hash, test_mode=engine.testMode))
 
         return True
+
+    def Storage_Find(self, engine):
+        context = engine.EvaluationStack.Pop().GetInterface()
+        if context is None:
+            return False
+
+        if not self.CheckStorageContext(context):
+            return False
+
+        prefix = engine.EvaluationStack.Pop().GetByteArray()
+        prefix = context.ScriptHash.ToArray() + prefix
+
+        iterator = self._storages.TryFind(prefix)
+        engine.EvaluationStack.PushT(StackItem.FromInterface(iterator))
+
+        return True
+
+    def Iterator_Next(self, engine):
+        iterator = engine.EvaluationStack.Pop().GetInterface()
+        if iterator is None:
+            return False
+
+        engine.EvaluationStack.PushT(iterator.Next())
+        return True
+
+    def Iterator_Key(self, engine):
+        iterator = engine.EvaluationStack.Pop().GetInterface()
+        if iterator is None:
+            return False
+
+        engine.EvaluationStack.PushT(iterator.Key())
+        return True
+
+    def Iterator_Value(self, engine):
+        iterator = engine.EvaluationStack.Pop().GetInterface()
+        if iterator is None:
+            return False
+
+        engine.EvaluationStack.PushT(iterator.Value())
+        return True
