@@ -1,15 +1,15 @@
 
-class EquatableMixin():
+class EquatableMixin:
 
     def Equals(self, other):
         pass
 
 
-class InteropMixin():
+class InteropMixin:
     pass
 
 
-class ScriptTableMixin():
+class ScriptTableMixin:
 
     def GetScript(self, script_hash):
         pass
@@ -21,7 +21,7 @@ class ScriptContainerMixin(InteropMixin):
         pass
 
 
-class CryptoMixin():
+class CryptoMixin:
 
     def Hash160(self, message):
         pass
