@@ -1,4 +1,3 @@
-# -*- coding:utf-8 -*-
 """
 Description:
     Wallet
@@ -6,6 +5,7 @@ Usage:
     from neo.Wallets.Wallet import Wallet
 """
 import traceback
+import hashlib
 from itertools import groupby
 from base58 import b58decode
 from decimal import Decimal
@@ -19,7 +19,7 @@ from neo.Core.State.CoinState import CoinState
 from neo.Core.Blockchain import Blockchain
 from neo.Core.CoinReference import CoinReference
 from neo.Core.TX.ClaimTransaction import ClaimTransaction
-from neocore.Cryptography.Helper import *
+from neocore.Cryptography.Helper import scripthash_to_address
 from neocore.Cryptography.Crypto import Crypto
 from neo.Wallets.AddressState import AddressState
 from neo.Wallets.Coin import Coin
@@ -34,7 +34,7 @@ from neo.Core.Helper import Helper
 from neo.Wallets.utils import to_aes_key
 
 
-class Wallet(object):
+class Wallet:
     AddressVersion = None
 
     _path = ''
@@ -67,7 +67,7 @@ class Wallet(object):
 
         Args:
             path (str): A path indicating where to create or open the wallet.
-            passwordKey (str): A password to use in creating or opening the wallet.
+            passwordKey (aes_key): A password that has been converted to aes key with neo.Wallets.utils.to_aes_key
             create (bool): Whether to create the wallet or simply open.
         """
 
@@ -199,7 +199,7 @@ class Wallet(object):
             token (UInt160): Token Contract script hash
 
         Returns:
-            bool: success status.
+            NEP5Token: the token object removed from the wallet
         """
         return self._tokens.pop(script_hash.ToBytes())
 
@@ -646,7 +646,7 @@ class Wallet(object):
         # abstract
         pass
 
-    def ProcessBlocks(self, block_limit=1000):
+    def ProcessBlocks(self, block_limit=10000):
         """
         Method called on a loop to check the current height of the blockchain.  If the height of the blockchain
         is more than the current stored height in the wallet, we get the next block in line and
@@ -671,6 +671,8 @@ class Wallet(object):
                 blockcount += 1
 
             self.SaveStoredData("Height", self._current_height)
+        except Exception as e:
+            logger.warn("Could not process ::: %s " % e)
         finally:
             self._lock.release()
 
@@ -699,7 +701,6 @@ class Wallet(object):
                     if state & AddressState.InWallet > 0:
 
                         # if its in the wallet, check to see if the coin exists yet
-
                         key = CoinReference(tx.Hash, index)
 
                         # if it exists, update it, otherwise create a new one
@@ -708,7 +709,7 @@ class Wallet(object):
                             coin.State |= CoinState.Confirmed
                             changed.add(coin)
                         else:
-                            newcoin = Coin.CoinFromRef(coin_ref=key, tx_output=output, state=CoinState.Confirmed)
+                            newcoin = Coin.CoinFromRef(coin_ref=key, tx_output=output, state=CoinState.Confirmed, transaction=tx)
                             self._coins[key] = newcoin
                             added.add(newcoin)
 
