@@ -35,11 +35,13 @@ from neo.Prompt.Commands.LoadSmartContract import LoadContract, GatherContractDe
 from neo.Prompt.Commands.Send import construct_and_send, parse_and_sign
 from neo.contrib.nex.withdraw import RequestWithdrawFrom, PrintHolds, DeleteHolds, WithdrawOne, WithdrawAll, \
     CancelWithdrawalHolds, ShowCompletedHolds, CleanupCompletedHolds
+
 from neo.Prompt.Commands.Tokens import token_approve_allowance, token_get_allowance, token_send, token_send_from, \
-    token_mint, token_crowdsale_register
+    token_mint, token_crowdsale_register, token_history
 from neo.Prompt.Commands.Wallet import DeleteAddress, ImportWatchAddr, ImportToken, ClaimGas, DeleteToken, AddAlias, \
     ShowUnspentCoins
-from neo.Prompt.Utils import get_arg, get_from_addr
+
+from neo.Prompt.Utils import get_arg, get_from_addr, get_tx_attr_from_args, get_owners_from_params
 from neo.Prompt.InputParser import InputParser
 from neo.Settings import settings, PrivnetConnectionError, PATH_USER_DATA
 from neo.UserPreferences import preferences
@@ -88,7 +90,7 @@ class PromptFileHistory(FileHistory):
         return string
 
 
-class PromptInterface(object):
+class PromptInterface:
     go_on = True
 
     _walletdb_loop = None
@@ -127,7 +129,7 @@ class PromptInterface(object):
                 'open wallet {path}',
                 'create wallet {path}',
                 'wallet {verbose}',
-                'wallet claim',
+                'wallet claim (max_coins_to_claim)',
                 'wallet migrate',
                 'wallet rebuild {start block}',
                 'wallet delete_addr {addr}',
@@ -139,6 +141,7 @@ class PromptInterface(object):
                 'wallet tkn_allowance {token symbol} {address_from} {address to}',
                 'wallet tkn_mint {token symbol} {mint_to_addr} (--attach-neo={amount}, --attach-gas={amount})',
                 'wallet tkn_register {addr} ({addr}...) (--from-addr={addr})',
+                'wallet tkn_history {token symbol}',
                 'wallet unspent',
                 'wallet close',
                 'withdraw_request {asset_name} {contract_hash} {to_addr} {amount}',
@@ -192,7 +195,7 @@ class PromptInterface(object):
                                 'wallet', 'contract', 'asset', 'wif',
                                 'watch_addr', 'contract_addr', 'testinvoke', 'tkn_send',
                                 'tkn_mint', 'tkn_send_from', 'tkn_approve', 'tkn_allowance',
-                                'tkn_register', 'build', 'notifications', ]
+                                'tkn_register', 'build', 'notifications', 'tkn_history']
 
         if self.Wallet:
             for addr in self.Wallet.Addresses:
@@ -565,6 +568,9 @@ class PromptInterface(object):
             token_mint(self.Wallet, arguments[1:])
         elif item == 'tkn_register':
             token_crowdsale_register(self.Wallet, arguments[1:])
+        elif item == 'tkn_history':
+            notification_db = NotificationDB.instance()
+            token_history(self.Wallet, notification_db, arguments[1:])
         elif item == 'unspent':
             ShowUnspentCoins(self.Wallet, arguments[1:])
         elif item == 'alias':
@@ -591,22 +597,26 @@ class PromptInterface(object):
         difftime = now - self.start_dt
 
         mins = difftime / datetime.timedelta(minutes=1)
+        secs = mins * 60
 
         bpm = 0
+        tps = 0
         if diff > 0 and mins > 0:
             bpm = diff / mins
+            tps = Blockchain.Default().TXProcessed / secs
 
         out = "Progress: %s / %s\n" % (height, headers)
         out += "Block-cache length %s\n" % Blockchain.Default().BlockCacheCount
         out += "Blocks since program start %s\n" % diff
         out += "Time elapsed %s mins\n" % mins
         out += "Blocks per min %s \n" % bpm
+        out += "TPS: %s \n" % tps
         tokens = [(Token.Number, out)]
         print_tokens(tokens, self.token_style)
 
     def show_nodes(self):
         if len(NodeLeader.Instance().Peers) > 0:
-            out = "Total Connected: %s " % len(NodeLeader.Instance().Peers)
+            out = "Total Connected: %s\n" % len(NodeLeader.Instance().Peers)
             for peer in NodeLeader.Instance().Peers:
                 out += "Peer %s - IO: %s\n" % (peer.Name(), peer.IOStats())
             print_tokens([(Token.Number, out)], self.token_style)
@@ -747,11 +757,11 @@ class PromptInterface(object):
         if not self.Wallet:
             print("Please open a wallet")
             return
-
         args, from_addr = get_from_addr(args)
-
+        args, invoke_attrs = get_tx_attr_from_args(args)
+        args, owners = get_owners_from_params(args)
         if args and len(args) > 0:
-            tx, fee, results, num_ops = TestInvokeContract(self.Wallet, args, from_addr=from_addr)
+            tx, fee, results, num_ops = TestInvokeContract(self.Wallet, args, from_addr=from_addr, invoke_attrs=invoke_attrs, owners=owners)
 
             if tx is not None and results is not None:
                 print(
@@ -765,12 +775,13 @@ class PromptInterface(object):
                     "-------------------------------------------------------------------------------------------------------------------------------------\n")
                 print("Enter your password to continue and invoke on the network\n")
 
+                tx.Attributes = invoke_attrs
+
                 passwd = prompt("[password]> ", is_password=True)
                 if not self.Wallet.ValidatePassword(passwd):
                     return print("Incorrect password")
 
-                result = InvokeContract(self.Wallet, tx, fee, from_addr=from_addr)
-
+                InvokeContract(self.Wallet, tx, fee, from_addr=from_addr, owners=owners)
                 return
             else:
                 print("Error testing contract invoke")
@@ -1003,6 +1014,11 @@ class PromptInterface(object):
                         self.handle_debug_storage(arguments)
                     elif command == 'config':
                         self.configure(arguments)
+                    elif command == 'pause':
+                        Blockchain.Default().Pause()
+                    elif command == 'resume':
+                        Blockchain.Default().Resume()
+
                     elif command is None:
                         print("Please specify a command")
                     else:
@@ -1051,6 +1067,10 @@ def main():
 
     args = parser.parse_args()
 
+    # Setting the datadir must come before setting the network, else the wrong path is checked at net setup.
+    if args.datadir:
+        settings.set_data_dir(args.datadir)
+
     # Setup depending on command line arguments. By default, the testnet settings are already loaded.
     if args.config:
         settings.setup(args.config)
@@ -1071,9 +1091,6 @@ def main():
     if args.verbose:
         settings.set_log_smart_contract_events(True)
 
-    if args.datadir:
-        settings.set_data_dir(args.datadir)
-
     if args.maxpeers:
         settings.set_max_peers(args.maxpeers)
 
